GasComp - Thermodynamic properties calculations for gas compositions
====================================================================

GasComp is a package for thermodynamic calculations of properties and state changes of gas compositions.

GasComp has the following capabilities:

- Calculation of thermodynamic properties of gas compositions.
- Calculation of thermodynamic state changes of gas compositions.

For now, the Benedict-Webb-Rubin (BWR) equation of state is implememted.

Everybody is welcome to use GasComp. 

Documentation
=============

You can find the full documentation at `readthedocs <http://gascomp.readthedocs.org>`_.

Installation
============

GasComp requires Python 3.8 or higher. It can be installed from Anaconda prompt
using ``pip``.

.. code:: bash

    pip install gascomp

License
=======

Copyright (C) 2020-2021 Michael Fischer.

GasComp is open source software; you can redistribute it and/or modify it under the terms of
the GPL-3.0 license.
